@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import contextlib
 import enum
 import json
 from pathlib import Path
@@ -14,6 +13,7 @@ from compass.core._scrapers.hierarchy import TYPES_ENDPOINT_LEVELS
 from compass.core.logger import logger
 from compass.core.logon import Logon
 from compass.core.schemas import hierarchy as schema
+from compass.core.settings import Settings
 from compass.core.util import context_managers
 
 if TYPE_CHECKING:
@@ -140,13 +140,14 @@ class Hierarchy:
 
         filename = Path(f"hierarchy-{unit_level.unit_id}.json")
         # Attempt to see if the hierarchy has been fetched already and is on the local system
-        with contextlib.suppress(FileNotFoundError):
-            out = json.loads(filename.read_text(encoding="utf-8"))
-            if isinstance(out, dict):
-                return schema.UnitData.parse_obj(out)
+        with context_managers.get_cached_json(filename, expected_type=dict) as cached_data:
+            if cached_data is not None:
+                return schema.UnitData.parse_obj(cached_data)
 
         # Fetch the hierarchy
         out = self._get_descendants_recursive(unit_level.unit_id, hier_level=unit_level.level)
+        if Settings.cache_to_file is False:
+            return schema.UnitData.parse_obj(out)
 
         # Try and write to a file for caching
         with context_managers.filesystem_guard("Unable to write cache file"):
@@ -192,33 +193,6 @@ class Hierarchy:
 
         return descendant_data
 
-    @staticmethod
-    def flatten_hierarchy(hierarchy_dict: schema.UnitData) -> Iterator[HierarchyState]:  # noqa: D417 (hanging indent)
-        """Flattens a hierarchy tree / graph to a flat sequence of mappings.
-
-        Args:
-            hierarchy_dict:
-                The current object to be flattened. The user will pass in a `schema.UnitData`
-                object, whilst all recursion will be on `schema.DescendantData` objects.
-
-        """
-        # This args style is allowed, but not yet (2021-03-20) implemented in PyDocStyle, so D417 disabled above.
-        # https://github.com/PyCQA/pydocstyle/issues/449
-        def flatten(d: Union[schema.UnitData, schema.DescendantData], hierarchy_state: HierarchyState) -> Iterator[HierarchyState]:
-            """Generator expresion to recursively flatten hierarchy."""
-            level_name = d.level
-            unit_id = d.unit_id
-            name = d.name if isinstance(d, schema.DescendantData) else None
-            level_data = hierarchy_state | {f"{level_name}_ID": unit_id, f"{level_name}_name": name}  # type: ignore[operator]
-            yield cast(HierarchyState, {"compass": unit_id, "name": name, "section": False} | level_data)
-            for child in d.child or []:
-                yield from flatten(child, cast(HierarchyState, level_data))
-            for section in d.sections:
-                yield cast(HierarchyState, {"compass": section.unit_id, "name": section.name, "section": True} | level_data)
-
-        blank_state: HierarchyState = dict()
-        return flatten(hierarchy_dict, blank_state)
-
     def get_unique_members(
         self,
         unit_level: Optional[schema.HierarchyLevel] = None,
@@ -251,7 +225,7 @@ class Hierarchy:
         hierarchy_dict = self.get_hierarchy(unit_level)
 
         # flatten tree
-        flat_hierarchy = self.flatten_hierarchy(hierarchy_dict)
+        flat_hierarchy = flatten_hierarchy(hierarchy_dict)
 
         # generator for compass unit IDs
         compass_ids = (unit["compass"] for unit in flat_hierarchy)
@@ -265,11 +239,10 @@ class Hierarchy:
     def get_members_in_units(self, parent_id: int, compass_ids: Iterable[int]) -> list[schema.HierarchyUnitMembers]:
         filename = Path(f"all-members-{parent_id}.json")
 
-        with contextlib.suppress(FileNotFoundError):
+        with context_managers.get_cached_json(filename, expected_type=list) as cached_data:
             # Attempt to see if the members dict has been fetched already and is on the local system
-            json_members: list[dict[str, list[dict[str, Union[None, int, str]]]]] = json.loads(filename.read_text(encoding="UTF8"))
-            if isinstance(json_members, list):
-                return [schema.HierarchyUnitMembers.parse_obj(unit_members) for unit_members in json_members]
+            if cached_data is not None:
+                return [schema.HierarchyUnitMembers.parse_obj(unit_members) for unit_members in cached_data]
 
         # Fetch all members
         all_members = []
@@ -278,8 +251,38 @@ class Hierarchy:
             data = schema.HierarchyUnitMembers(unit_id=unit_id, member=self._scraper.get_members_with_roles_in_unit(unit_id))
             all_members.append(data)
 
+        if Settings.cache_to_file is False:
+            return all_members
+
         # Try and write to a file for caching
         with context_managers.filesystem_guard("Unable to write cache file"):
             filename.write_text(json.dumps(all_members, ensure_ascii=False, indent=4, default=pydantic_encoder), encoding="utf-8")
 
         return all_members
+
+
+def flatten_hierarchy(hierarchy_dict: schema.UnitData) -> Iterator[HierarchyState]:  # noqa: D417 (hanging indent)
+    """Flattens a hierarchy tree / graph to a flat sequence of mappings.
+
+    Args:
+        hierarchy_dict:
+            The current object to be flattened. The user will pass in a `schema.UnitData`
+            object, whilst all recursion will be on `schema.DescendantData` objects.
+
+    """
+    # This args style is allowed, but not yet (2021-03-20) implemented in PyDocStyle, so D417 disabled above.
+    # https://github.com/PyCQA/pydocstyle/issues/449
+    def flatten(d: Union[schema.UnitData, schema.DescendantData], hierarchy_state: HierarchyState) -> Iterator[HierarchyState]:
+        """Generator expresion to recursively flatten hierarchy."""
+        level_name = d.level
+        unit_id = d.unit_id
+        name = d.name if isinstance(d, schema.DescendantData) else None
+        level_data = hierarchy_state | {f"{level_name}_ID": unit_id, f"{level_name}_name": name}  # type: ignore[operator]
+        yield cast(HierarchyState, {"compass": unit_id, "name": name, "section": False} | level_data)
+        for child in d.child or []:
+            yield from flatten(child, cast(HierarchyState, level_data))
+        for section in d.sections:
+            yield cast(HierarchyState, {"compass": section.unit_id, "name": section.name, "section": True} | level_data)
+
+    blank_state: HierarchyState = dict()
+    return flatten(hierarchy_dict, blank_state)
